/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication.http
 * File:    BasicAuth.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication.http;

import org.apache.commons.codec.binary.Base64;
import org.apache.http.HeaderElement;
import org.apache.http.HeaderElementIterator;
import org.apache.http.HttpRequest;
import org.apache.http.message.BasicHeaderElementIterator;
import org.apache.log4j.Logger;

import de.fhhannover.inform.iron.mapserver.communication.ClientIdentifier;
import de.fhhannover.inform.iron.mapserver.logging.Logging;
import de.fhhannover.inform.iron.mapserver.provider.BasicAuthProvider;

/**
 * Implements the basic access authentication described in RFC 1945, 2616 and 2617.
 * 
 * @author tr
 * 
 * aw: Did some changes when changing the interface :-/
 * 
 * TODO: Does it make sense to check whether if mClientId is already set that
 *       the client tries to authenticate with the same username as before?
 *       Currently, we create a new ClientIdentifier each time we enter
 *       authenticate().
 *
 */

public class BasicAuth implements ChannelAuth {

	private ClientIdentifier mClientId;
	private BasicAuthProvider mBasicAuthProvider;
	
	private static Logger sLogger;
	{
		sLogger = Logging.getTheLogger();
	}
	
	public BasicAuth(BasicAuthProvider basicAuthProv){
		mBasicAuthProvider = basicAuthProv;
	}
	
	@Override
	public void authenticate(HttpRequest request) throws AuthException {
		HeaderElementIterator it = 
			new BasicHeaderElementIterator(request.headerIterator("Authorization"));
		HeaderElement elem;
		if(it.hasNext()){
			elem = it.nextElement();			
		}
		else throw new AuthException("No Authorization field found, cannot authenticate client!");
			
		String base64 = elem.getName().split(" ")[1];		
		
		String[] creds = new String(Base64.decodeBase64(base64)).split(":");
		
		if(creds.length != 2){
			throw new AuthException("Wrong credentials, not authenticated!");
		}
		
		String user = creds[0];
		String pass = creds[1];

		if(!mBasicAuthProvider.verify(user, pass)){
			sLogger.debug("Rejected basic client " + user);
			throw new AuthException("Wrong credentials, not authenticated!");
		} else {
			sLogger.debug("Accepted basic client " + user);
			ClientIdentifier newClId = new ClientIdentifier(user);
			
			if (mClientId != null) {
				if (!mClientId.equals(newClId)) {
					throw new AuthException("Something bad happened");
				}
			} else {
				mClientId = newClId;
			}
		}
	}

	@Override
	public ClientIdentifier getClientIdentifier() {
		return mClientId;
	}

}
