/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    Subscription.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import java.util.LinkedList;
import java.util.List;

import de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer;
import de.fhhannover.inform.iron.mapserver.messages.SearchRequest;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;
/**
 * A subscription object encapsulates a {@link SearchRequest} and 
 * four different {@link SearchRequest} objects. Update, delete, notify and
 * search.
 * 
 * 
 * @version 0.1
 * @author aw, vp
 */

/*
 * created: 03.05.10
 * 
 * changes:
 *  03.05.10 aw, vp  ...
 *  08.06.10 aw - some commenting and minor changes
 *  11.06.10 aw - add names to the search results :-/
 * 
 * 
 */
public class Subscription {
	
	
	/**
	 * Name of the subscription
	 */
	private String name;
	
	/**
	 * Corresponding searchRequest
	 */
	private SearchRequest searchRequest;
	
	/**
	 * List of containers where the subscription is active
	 */
	private List<MetadataContainer> containers;
	
	private SearchResult searchResult;
	private SearchResult updateResult;
	private SearchResult deleteResult;
	private SearchResult notifyResult;
	
	private SearchResult reRunOldResult;
	private SearchResult reRunNewResult;

	private boolean changed;

	public Subscription(String name, SearchRequest searchRequest) {
		this.name			= new String(name);
		this.searchRequest	= searchRequest;
		this.containers		= new LinkedList<MetadataContainer>();
		resetResults();
	}
			

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}


	/*
	 * auto generated getters and setters
	 */
	public SearchRequest getSearchRequest() {
		return searchRequest;
	}
	
	public void setSearchRequest(SearchRequest sReq) {
		searchRequest = sReq;
	}


	public List<MetadataContainer> getContainers() {
		return containers;
	}


	public void emptyPollResult() {
		throw new RuntimeException("Not implemented");
	}


	public void addContainer(MetadataContainer mc) {
		containers.add(mc);
	}


	public void setSearchResult(SearchResult sres) {
		searchResult = sres;
	}

	public SearchResult getUpdateResult() {
		return updateResult;
	}
	
	public SearchResult getSearchResult() {
		return searchResult;
	}


	public SearchResult getDeleteResult() {
		return deleteResult;
	}
	
	public SearchResult getNotifyResult() {
		return notifyResult;
	}


	public void setReRunOldResult(SearchResult reRunOldResult) {
		this.reRunOldResult = reRunOldResult;
	}


	public SearchResult getReRunOldResult() {
		return reRunOldResult;
	}


	public void setReRunNewResult(SearchResult reRunNewResult) {
		this.reRunNewResult = reRunNewResult;
	}


	public SearchResult getReRunNewResult() {
		return reRunNewResult;
	}


	public void setChanged() {
		changed = true;
	}
	
	
	public boolean hasChanged() {
		return changed;
	}


	public void resetResults() {
		changed = false;
		this.updateResult	= new SearchResultImpl(searchRequest.getSessionId(), this.name);
		this.searchResult	= new SearchResultImpl(searchRequest.getSessionId(), this.name);
		this.deleteResult	= new SearchResultImpl(searchRequest.getSessionId(), this.name);
		this.notifyResult	= new SearchResultImpl(searchRequest.getSessionId(), this.name);
	}
}
