/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    SearchRequest.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.Filter;

/**
 * Message to be passed to the DataModelService instance
 * if a search needs to be done. One should use a constructor
 * to build this Request.
 * 
 * @author aw
 * @version 0.1
 */

/* 
 * created: 09.12.09
 * changes:
 * 	09.12.09 aw - Created first version of this class.
 *  05.02.10 aw - use Request superclass
 *  02.12.10 aw - Use RequestWithSessionId as superclass, make fields final
 *
 */
public class SearchRequest extends RequestWithSessionId {
 
	public static final int MAX_RESULT_SIZE_NOT_GIVEN = -1;

	private final int maxDepth;
	 
	private final int maxResultSize;
	 
	private final String terminalIdentifierTypes;
	 
	private final Identifier start;
	 
	private final Filter matchLinksFilter;
	 
	private final Filter resultFilter;
	

	/**
	 * TODO: Check for null!!!
	 * 
	 * @param maxDepth
	 * @param maxResultSize
	 * @param terminalIdentTypes
	 * @param start
	 * @param matchLinksFilter
	 * @param resultFilter
	 * @throws RequestCreationException 
	 */
	SearchRequest(String sessionid, int maxDepth, int maxResultSize,
								String terminalIdentTypes, Identifier start,
								Filter matchLinksFilter, Filter resultFilter)
											throws RequestCreationException {
		
		super(sessionid);
		this.maxDepth = maxDepth;
		this.maxResultSize = maxResultSize;
		this.terminalIdentifierTypes = terminalIdentTypes;
		this.start = start;
		this.matchLinksFilter = matchLinksFilter;
		this.resultFilter = resultFilter;
	}
	
	public int getMaxDepth() {
		return maxDepth;
	}

	public int getMaxResultSize() {
		return maxResultSize;
	}

	public String getTerminalIdentifierTypes() {
		return terminalIdentifierTypes;
	}

	public Identifier getStartIdentifier() {
		return start;
	}

	public Filter getMatchLinksFilter() {
		return matchLinksFilter;
	}

	public Filter getResultFilter() {
		return resultFilter;
	}

}
 
