/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.utils
 * File:    RequestTransformer.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.utils;

import java.io.InputStream;

import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.IdentifierConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.MetadataConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.messages.PublishRequest;
import de.fhhannover.inform.iron.mapserver.messages.Request;

/**
 * Interface to offer functionality to transform the content of a request sent
 * by a MAPC into a framework independent {@link Request} implementation object.
 * 
 * @author aw
 */
public interface RequestTransformer {
	
	/**
	 * Transform the content of a request to a corresponding {@link Request}
	 * implementation.
	 * 
	 * The following steps have to be done:
	 * <li>Unmarshal the content</li>
	 * <li>Find the content of the SOAP Body</li>
	 * <li>Create a object of a appropiate {@link Request} implementation</li>
	 * 
	 * @param requestContent XML document containing a SOAP Envelope, Body,
	 *        and a IF-MAP operation
	 * @return
	 * @throws RequestCreationException if something is wrong with the {@link Request}.
	 * @throws IdentifierConstructionException if a {@link Identifier} inside a
	 *         {@link Request} is bad.
	 * @throws MetadataConstructionException if something is wrong with the
	 *         metadata inside a {@link PublishRequest}.
	 */
	public Request transform(InputStream requestContent) throws RequestCreationException, IdentifierConstructionException, MetadataConstructionException;
}
