/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.utils
 * File:    ResponseCreator.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.utils;

import java.io.InputStream;


import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.ResponseCreationException;
import de.fhhannover.inform.iron.mapserver.messages.DumpResult;
import de.fhhannover.inform.iron.mapserver.messages.ErrorCode;
import de.fhhannover.inform.iron.mapserver.messages.PollResult;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;

/**
 * Can create all outgoing messages in form of {@link InputStream} objects
 * using a implementation of this interface.
 * 
 * The returned {@link InputStream} for each method is going to be used as
 * content for the HTTP body, so the content should be a XML document...
 * 
 * TODO: The methods name should be enough to describe the functionality?
 * 
 * @author aw
 */
public interface ResponseCreator {
	
	/**
	 * Response which has session-id and ifmap-publisher-id set.
	 * max-poll-result-size is unset.
	 * 
	 * @param sessionId
	 * @param publisherId
	 * @return
	 * @throws ResponseCreationException
	 */
	InputStream createNewSessionResponse(String sessionId, String publisherId);
	
	/**
	 * Response which has session-id and ifmap-publisher-id set.
	 * max-poll-result-size is set in this case.
	 * 
	 * @param sessionId
	 * @param publisherId
	 * @return
	 * @throws ResponseCreationException
	 */
	InputStream createNewSessionResponse(String sessionId, String publisherId,
			long maxPollResultSize); 
	
	public InputStream createEndSessionResponse(); 
	
	public InputStream createRenewSessionResponse();
	
	public InputStream createPublishResponse();
	
	public InputStream createPurgePublisherResponse();
	
	public InputStream createSubscribeResponse();
	
	public InputStream createErrorResponse(ErrorCode errorCode, String errorString);
	
	public InputStream createSearchResponse(SearchResult searchResult);
	
	public InputStream createDumpResponse(DumpResult dumpResult);
	
	public InputStream createPollResponse(PollResult pollResult);

	public InputStream createPollResponseError(ErrorCode errCode, String errMsg,
			String subName);

}
